==> xmgfv1.9.1.tar.gz: xmgf/inc/Menus.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */


extern Widget          QuttButt,LineDot,LineDas,SaveASTitleSep,PointTypeTitle;
extern Widget          Line0pt, Line1pt, Line2pt, Line3pt, Line4pt, Line5pt;
extern Widget          w_PTBox, w_PTTri, w_PTPlus, w_PTCross, w_PTFillBox;
extern Widget          FileSelector,w_PTFillTri,w_PTCircle,PointTypeTitleSep;
extern Widget          NoFill, DoFill, Hide_Line, BlackFill, WhiteFill, OpaqueFill;
extern Widget          ShFill, ShadeLines, PointSFill, RotBB,DoubleBuffer,LoadButt;
extern Widget          BackGrdImage;
extern Widget          SaveButt, SaveAsButt,LoadColourMapButt,LoadGreyMapButt;
extern Widget          PointTyp1, PointTyp2, PointTyp3, PointTyp4, PointTyp5;
extern Widget          SelLabels, SelExpand,DepthCue,AutoSTButt,FixateTButt;
extern Widget          PointTyp6, PointTyp7, PointTyp8, PointSize,SaveASTitle;
extern Widget          LoadParmButt, SaveParmButt, AboutButt, PrintButt,SavePSButt;
extern Widget          SavePSButtCol, SavePSPButt, SavePSPButtCol,PrintColourBB;
extern Widget          SaveFIGButt,SaveFIGButtCol,SavePGMButt,SaveXBMButt;
extern Widget          SaveRAYButt,SelPoints,AppendButt,BackGrdColour,w_PTPoint;
extern Widget          SavePPMButt,SaveGIFButt,SaveRASButt,SaveRASButtCol;
extern Widget          ImportOFFButt, ImportNFFButt, ImportRAYButt, ImportTitle;
extern Widget          ImportSLAButt, ImportOBJButt,ImportTitleSep,SavePBMButt;
extern Widget          LoadFileSel, AppendFileSel, SaveFileSel,DrawAxisLabel;
extern Widget          AboutShellDia, PrintShellDia, FillShellDia, PtSizeShellDia;
extern Widget          ARPhiScal, ARGammaScal, ARThetaScal, ATRotSize,LandScapeBB;
extern Widget          w_FileSelectorDia,PtSizeScal,LineSol,OrthOPro;
extern Widget		AxisSizeShellDia,AxisSizeScal,PointTyp9,w_PTFillCircle;
extern Widget		AnimSpeedShellDia,AnimSpeedScal;
extern Widget 		OutLineBu,ColDither;
/*extern Widget 	       w_FileSelector;*/
extern char            SaveAsFilename[100];
extern char    *Selectedfilename;

#ifndef _NO_PROTO
void MakeLineWidthSubMenu(Widget parent);
void MakeLineStyleSubMenu(Widget parent);
void MakePointSubMenu(Widget parent);
void KillAboutCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillLineCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPointCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPolygonCB(Widget w, caddr_t client_data, caddr_t call_data);
void PrintXmgfCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPrintCB(Widget w, caddr_t client_data, caddr_t call_data);
void MakeIconPanel(Widget Parent,int Arrangement,Widget *Arr);
#else
void MakeLineWidthSubMenu();
void MakeLineStyleSubMenu();
void MakePointSubMenu();
void KillAboutCB();
void KillLineCB();
void KillPointCB();
void KillPolygonCB();
void PrintXmgfCB();
void KillPrintCB();
void MakeIconPanel();
#endif


#ifndef _NO_PROTO
void    BackFaceCB (Widget w, caddr_t client_data, caddr_t call_data);
void    SelColorCB (Widget w, caddr_t client_data, caddr_t call_data);
void    Create_Menus (void);
void    CreateAboutPanel (void);
void    CreateLinePanel (Widget w, caddr_t client_data, caddr_t call_data);
void    CreatePointPanel (Widget w, caddr_t client_data, caddr_t call_data);
void    CreatePolygonPanel (Widget w, caddr_t client_data, caddr_t call_data);
void    CreatePrintPanel (void);
void    MakeMenuButton (Widget Bar, Widget Pane, char *Title, char *ResName, char *Mnwm);
Widget  MakeFileSelector (Widget Parent, char *Title, int Funct);
int     DialogAcceptCB (Widget w, caddr_t client_data, caddr_t call_data);
int     DialogCancelCB (Widget w, caddr_t client_data, caddr_t call_data);
void    SetToggles (void);
void 	SetIconToggles(void);
#else
void            BackFaceCB ();
void            SelColorCB ();
void             Create_Menus ();
void          CreateAboutPanel ();
void          CreateLinePanel ();
void          CreatePointPanel ();
void          CreatePolygonPanel ();
void          CreatePrintPanel ();
void             MakeMenuButton ();
Widget          MakeFileSelector ();
int             DialogAcceptCB ();
int             DialogCancelCB ();
void            SetToggles ();
void 		SetIconToggles();
#endif

==> xmgfv2.4.tar.gz: xmgf/inc/Menus.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */


extern Widget          QuttButt,LineDot,LineDas,SaveASTitleSep,PointTypeTitle;
extern Widget          Line0pt, Line1pt, Line2pt, Line3pt, Line4pt, Line5pt;
extern Widget          w_PTBox, w_PTTri, w_PTPlus, w_PTCross, w_PTFillBox;
extern Widget          FileSelector,w_PTFillTri,w_PTCircle,PointTypeTitleSep;
extern Widget          NoFill, DoFill, Hide_Line, BlackFill, WhiteFill, OpaqueFill;
extern Widget          ShFill, ShadeLines, PointSFill, RotBB,DoubleBuffer,LoadButt;
extern Widget          BackGrdImage;
extern Widget          SaveButt, SaveAsButt,LoadColourMapButt,LoadGreyMapButt;
extern Widget          PointTyp1, PointTyp2, PointTyp3, PointTyp4, PointTyp5;
extern Widget          SelLabels, SelExpand,DepthCue,AutoSTButt,FixateTButt;
extern Widget          PointTyp6, PointTyp7, PointTyp8, PointSize,SaveASTitle;
extern Widget          LoadParmButt, SaveParmButt, AboutButt, PrintButt,SavePSButt;
extern Widget          SavePSButtCol, SavePSPButt, SavePSPButtCol,PrintColourBB;
extern Widget          SaveFIGButt,SaveFIGButtCol,SavePGMButt,SaveXBMButt;
extern Widget          SaveRAYButt,SelPoints,AppendButt,BackGrdColour,w_PTPoint;
extern Widget          SavePPMButt,SaveGIFButt,SaveRASButt,SaveRASButtCol;
extern Widget          ImportOFFButt, ImportNFFButt, ImportRAYButt, ImportTitle;
extern Widget          ImportSLAButt, ImportOBJButt,ImportTitleSep,SavePBMButt;
extern Widget          LoadFileSel, AppendFileSel, SaveFileSel,DrawAxisLabel;
extern Widget          AboutShellDia, PrintShellDia, FillShellDia, PtSizeShellDia;
extern Widget          ARPhiScal, ARGammaScal, ARThetaScal, ATRotSize,LandScapeBB;
extern Widget          w_FileSelectorDia,PtSizeScal,LineSol,OrthOPro;
extern Widget		AxisSizeShellDia,AxisSizeScal,PointTyp9,w_PTFillCircle;
extern Widget		AnimSpeedShellDia,AnimSpeedScal;
extern Widget 		OutLineBu,ColDither,PointCueW;
extern Widget 		w_PTFillSphere,HaloedFill,w_HalColor,w_RedBlue;
extern Widget		IconRowCol;
/*extern Widget 	       w_FileSelector;*/
extern char            SaveAsFilename[100];
extern char    *Selectedfilename;


#ifndef _NO_PROTO
void MakeLineWidthSubMenu(Widget parent);
void MakeLineStyleSubMenu(Widget parent);
void MakePointSubMenu(Widget parent);
void KillAboutCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillLineCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPointCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPolygonCB(Widget w, caddr_t client_data, caddr_t call_data);
void PrintXmgfCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPrintCB(Widget w, caddr_t client_data, caddr_t call_data);
Widget MakeIconPanel(Widget Parent,int Arrangement,Widget *Arr,Arg *farg,int fnum);
#else
void MakeLineWidthSubMenu();
void MakeLineStyleSubMenu();
void MakePointSubMenu();
void KillAboutCB();
void KillLineCB();
void KillPointCB();
void KillPolygonCB();
void PrintXmgfCB();
void KillPrintCB();
Widget MakeIconPanel();
#endif


#ifndef _NO_PROTO
void    BackFaceCB (Widget w, caddr_t client_data, caddr_t call_data);
void    SelColorCB (Widget w, caddr_t client_data, caddr_t call_data);
Widget    Create_Menus (Arg *farg,int fnum);
void    CreateAboutPanel (void);
void    CreateLinePanel (Widget w, caddr_t client_data, caddr_t call_data);
void    CreatePointPanel (Widget w, caddr_t client_data, caddr_t call_data);
void    CreatePolygonPanel (Widget w, caddr_t client_data, caddr_t call_data);
void    CreatePrintPanel (void);
void    MakeMenuButton (Widget Bar, Widget Pane, char *Title, char *ResName, char *Mnwm);
Widget  MakeFileSelector (Widget Parent, char *Title, int Funct);
int     DialogAcceptCB (Widget w, caddr_t client_data, caddr_t call_data);
int     DialogCancelCB (Widget w, caddr_t client_data, caddr_t call_data);
void    SetToggles (void);
void 	SetIconToggles(void);
#else
void          BackFaceCB ();
void          SelColorCB ();
Widget        Create_Menus ();
void          CreateAboutPanel ();
void          CreateLinePanel ();
void          CreatePointPanel ();
void          CreatePolygonPanel ();
void          CreatePrintPanel ();
void             MakeMenuButton ();
Widget          MakeFileSelector ();
int             DialogAcceptCB ();
int             DialogCancelCB ();
void            SetToggles ();
void 		SetIconToggles();
#endif
